# Jmespath-filters

[![Test](https://github.com/os4d/jmespath-filters/actions/workflows/test.yml/badge.svg)](https://github.com/os4d/jmespath-filters/actions/workflows/test.yml)
[![Lint](https://github.com/os4d/jmespath-filters/actions/workflows/lint.yml/badge.svg)](https://github.com/os4d/jmespath-filters/actions/workflows/lint.yml)
[![Documentation](https://github.com/os4d/jmespath-filters/actions/workflows/docs.yml/badge.svg)](https://github.com/os4d/jmespath-filters/actions/workflows/docs.yml)
[![codecov](https://codecov.io/github/os4d/jmespath-filters/graph/badge.svg?token=BNXEW4JAYF)](https://codecov.io/github/os4d/jmespath-filters)
[![security: bandit](https://img.shields.io/badge/security-bandit-yellow.svg)](https://github.com/PyCQA/bandit)
[![Publish Python 🐍 distribution 📦 to PyPI and TestPyPI](https://github.com/os4d/jmespath-filters/actions/workflows/release.yml/badge.svg)](https://github.com/os4d/jmespath-filters/actions/workflows/release.yml)
[![Pypi](https://badge.fury.io/py/jmespath-filters.svg)](https://badge.fury.io/py/jmespath-filters)
[![coverage](https://codecov.io/github/os4d/jmespath-filters/coverage.svg?branch=develop)](https://codecov.io/github/os4d/jmespath-filters?branch=develop)

Jmespathh-filters is a library providing a filtering utility for JSON payloads.

You can use it to evaluate a payload against an Expression and check if it is a match.

The Expression is based on the [JMESPath query language for JSON](https://jmespath.org/).
On the [JMESPath website](https://jmespath.org/) you can also find an interactive form for testing the syntax.


## Dependencies

* Python 3.10 or later


## Installation

* Install jmespath_filters using your package manager of choice, e.g. Pip:
  ```bash
  pip install jmespath-filters
  ```

## Bug reports and requests for enhancements

Please open an issue on the project's [issue tracker on GitHub](https://github.com/os4d/django_temporary_permissions/issues).

## Contributing to the project

See the [contribution guide](CONTRIBUTING.md).

## Licensing

All rights reserved.
